diff --git a/Community.PowerToys.Run.Plugin.Everything.csproj b/Community.PowerToys.Run.Plugin.Everything.csproj
index f095614..6b011c3 100644
--- a/Community.PowerToys.Run.Plugin.Everything.csproj
+++ b/Community.PowerToys.Run.Plugin.Everything.csproj
@@ -80,27 +80,13 @@
-
-
-
-
-
-
PublicResXFileCodeGenerator
Resources.Designer.cs
-
-
-
- Never
-
-
- Never
-
PreserveNewest
diff --git a/Community.PowerToys.Run.Plugin.Everything.xml b/Community.PowerToys.Run.Plugin.Everything.xml
deleted file mode 100644
index 1cfd981..0000000
--- a/Community.PowerToys.Run.Plugin.Everything.xml
+++ /dev/null
@@ -1,99 +0,0 @@
-
-
-
- Community.PowerToys.Run.Plugin.Everything
-
-
-
-
- A strongly-typed resource class, for looking up localized strings, etc.
-
-
-
-
- Returns the cached ResourceManager instance used by this class.
-
-
-
-
- Overrides the current thread's CurrentUICulture property for all
- resource lookups using this strongly typed resource class.
-
-
-
-
- Looks up a localized string similar to Fail to set text in clipboard.
-
-
-
-
- Looks up a localized string similar to Copy path (Ctrl+C).
-
-
-
-
- Looks up a localized string similar to Enable Wait setting under PowerToys Run > Everything.
-
-
-
-
- Looks up a localized string similar to Install Everything if not installed.
-
-
-
-
- Looks up a localized string similar to Everything is not running.
-
-
-
-
- Looks up a localized string similar to Fail to open folder at.
-
-
-
-
- Looks up a localized string similar to Open containing folder (Ctrl+Shift+E).
-
-
-
-
- Looks up a localized string similar to Open path in console (Ctrl+Shift+C).
-
-
-
-
- Looks up a localized string similar to Get search results from Everything.
-
-
-
-
- Looks up a localized string similar to Everything.
-
-
-
-
- Looks up a localized string similar to Preview - Preview file content as icon, may cause freezing if file is not local..
-
-
-
-
- Looks up a localized string similar to Run as administrator (Ctrl+Shift+Enter).
-
-
-
-
- Looks up a localized string similar to Timed out before finishing the query.
-
-
-
-
- Looks up a localized string similar to Top - Insert result at the top of the list, may cause pre-selection issue..
-
-
-
-
- Looks up a localized string similar to Wait - Wait longer for the query to finish, enable only if prompted to..
-
-
-
-
diff --git a/Interop/NativeMethods.cs b/Interop/NativeMethods.cs
index aac2a48..1a1cecd 100644
--- a/Interop/NativeMethods.cs
+++ b/Interop/NativeMethods.cs
@@ -59,6 +59,8 @@ namespace Community.PowerToys.Run.Plugin.Everything.Interop
#endregion
internal const string dllName = "Everything64.dll";
[LibraryImport(dllName)]
+ internal static partial void Everything_CleanUp();
+ [LibraryImport(dllName)]
internal static partial uint Everything_GetLastError();
[LibraryImport(dllName)]
internal static partial uint Everything_GetNumResults(); //Everything3_GetResultListCount
diff --git a/Main.cs b/Main.cs
index 1be9ea3..253946a 100644
--- a/Main.cs
+++ b/Main.cs
@@ -172,8 +172,7 @@ namespace Community.PowerToys.Run.Plugin.Everything
httpClient.DefaultRequestHeaders.UserAgent.ParseAdd("Mozilla/5.0");
string url = $"https://github.com/lin-ycv/EverythingPowerToys/raw/refs/heads/lib/Everything{(_isArm ? "ARM" : string.Empty)}64.dll";
byte[] fileContent = httpClient.GetByteArrayAsync(url).Result;
- string fileName = dll;
- File.WriteAllBytes(fileName, fileContent);
+ File.WriteAllBytes(dll, fileContent);
}
else
{
@@ -183,13 +182,12 @@ namespace Community.PowerToys.Run.Plugin.Everything
if (_setting.LoggingLevel <= LogLevel.Debug)
Log.Info("EPT: Init", GetType());
- if (_setting.Updates)
- {
- Update.UpdateSettings upSettings;
- upSettings = _storage.Load();
- Task.Run(() => new Update.UpdateChecker().Async(Assembly.GetExecutingAssembly().GetName().Version, _setting, upSettings, _isArm));
- }
+ Update.UpdateSettings upSettings = _storage.Load();
+ if (_setting.Updates)
+ Task.Run(() => new Update.UpdateChecker().Async(Assembly.GetExecutingAssembly().GetName().Version, _setting, upSettings, _isArm));
+
+ Thread.Sleep(500); // Wait for Everything to start
if (Everything_GetMinorVersion() < 5) _setting.Getfilters();
_everything = new Everything(_setting);
_contextMenuLoader = new ContextMenuLoader(context, _setting.Context);
@@ -277,6 +275,7 @@ namespace Community.PowerToys.Run.Plugin.Everything
{
cts.Cancel();
cts.Dispose();
+ Everything_CleanUp();
}
_disposed = true;
diff --git a/Properties/Resources.Designer.cs b/Properties/Resources.Designer.cs
index a94f9e8..3f5d9ec 100644
--- a/Properties/Resources.Designer.cs
+++ b/Properties/Resources.Designer.cs
@@ -80,7 +80,7 @@ namespace Community.PowerToys.Run.Plugin.Everything.Properties {
///
/// Looks up a localized string similar to Configure context menu options and order.
- ///0_Open folder, 1_Run as Admin, 2_Run as User, 3_Copy, 4_Copy Path, 5_Open in Console, 6_Open in custom program, 7_Delete file/folder, 8_Right click context menu.
+ ///0_Open folder, 1_Run as Admin, 2_Run as User, 3_Copy, 4_Copy Path, 5_Open in Console, 6_Open in custom program, 7_Delete file/folder, 8_Shell context menu.
///
public static string Context_Description {
get {
@@ -423,15 +423,6 @@ namespace Community.PowerToys.Run.Plugin.Everything.Properties {
}
}
- ///
- /// Looks up a localized string similar to Right click context menu (Ctrl+M).
- ///
- public static string right_click {
- get {
- return ResourceManager.GetString("right_click", resourceCulture);
- }
- }
-
///
/// Looks up a localized string similar to Run as administrator (Ctrl+Shift+Enter).
///
@@ -450,6 +441,15 @@ namespace Community.PowerToys.Run.Plugin.Everything.Properties {
}
}
+ ///
+ /// Looks up a localized string similar to Shell context menu (Ctrl+M).
+ ///
+ public static string scm {
+ get {
+ return ResourceManager.GetString("scm", resourceCulture);
+ }
+ }
+
///
/// Looks up a localized string similar to Show more.
///
diff --git a/Properties/Resources.es-es.resx b/Properties/Resources.es-es.resx
index 81f02dd..17e1aed 100644
--- a/Properties/Resources.es-es.resx
+++ b/Properties/Resources.es-es.resx
@@ -125,7 +125,7 @@
Configurar las opciones del menú contextual y su orden.
-0_Abrir carpeta, 1_Ejecutar como administrador, 2_Ejecutar como usuario, 3_Copiar, 4_Copiar ruta, 5_Abrir en el terminal
+0_Abrir carpeta, 1_Ejecutar como administrador, 2_Ejecutar como usuario, 3_Copiar, 4_Copiar ruta, 5_Abrir en el terminal, 6_Open in custom program, 7_Delete file/folder, 8_Shell context menu
Copiar
diff --git a/Properties/Resources.it-it.resx b/Properties/Resources.it-it.resx
index 1b0ad14..a52f278 100644
--- a/Properties/Resources.it-it.resx
+++ b/Properties/Resources.it-it.resx
@@ -125,7 +125,7 @@
Configura le opzioni e l'ordine del menu contestuale.
-0_Apri cartella, 1_Esegui come Amministratore, 2_Esegui come Utente, 3_Copia, 4_Copia Percorso, 5_Apri nella Console, 6_Apri con programma esterno
+0_Apri cartella, 1_Esegui come Amministratore, 2_Esegui come Utente, 3_Copia, 4_Copia Percorso, 5_Apri nella Console, 6_Apri con programma esterno, 7_Delete file/folder, 8_Shell context menu
Copia
diff --git a/Properties/Resources.pl-pl.resx b/Properties/Resources.pl-pl.resx
index b2e4bec..cba334a 100644
--- a/Properties/Resources.pl-pl.resx
+++ b/Properties/Resources.pl-pl.resx
@@ -125,7 +125,7 @@
Skonfiguruj opcje i kolejność menu kontekstowego.
-0_Otwórz folder, 1_Uruchom jako administrator, 2_Uruchom jako użytkownik, 3_Kopiuj plik, 4_Kopiuj ścieżkę, 5_Otwórz w konsoli
+0_Otwórz folder, 1_Uruchom jako administrator, 2_Uruchom jako użytkownik, 3_Kopiuj plik, 4_Kopiuj ścieżkę, 5_Otwórz w konsoli, 6_Open in custom program, 7_Delete file/folder, 8_Shell context menu
Kopiuj plik
diff --git a/Properties/Resources.resx b/Properties/Resources.resx
index be6cba5..501920c 100644
--- a/Properties/Resources.resx
+++ b/Properties/Resources.resx
@@ -125,7 +125,7 @@
Configure context menu options and order.
-0_Open folder, 1_Run as Admin, 2_Run as User, 3_Copy, 4_Copy Path, 5_Open in Console, 6_Open in custom program, 7_Delete file/folder, 8_Right click context menu
+0_Open folder, 1_Run as Admin, 2_Run as User, 3_Copy, 4_Copy Path, 5_Open in Console, 6_Open in custom program, 7_Delete file/folder, 8_Shell context menu
Copy
@@ -271,8 +271,8 @@ Latest: {1}
The "Include inglobal result" option is turned on for the History plugin, which could lead to conflicts with EPT.
-
- Right click context menu (Ctrl+M)
+
+ Shell context menu (Ctrl+M)
Delete file/folder (Ctrl+Del)
diff --git a/Properties/Resources.zh-cn.resx b/Properties/Resources.zh-cn.resx
index eb60b01..d907d95 100644
--- a/Properties/Resources.zh-cn.resx
+++ b/Properties/Resources.zh-cn.resx
@@ -126,7 +126,7 @@
配置选单选项与顺序
-0_打开所在文件夹、1_以管理员身分运行、2_以不同的使用者身分运行、3_复制、4_复制路径、5_在控制台中开启
+0_打开所在文件夹、1_以管理员身分运行、2_以不同的使用者身分运行、3_复制、4_复制路径、5_在控制台中开启、6_在指定軟體中開啟、 7_刪除檔案/資料夾、 8_右鍵選單
复制
diff --git a/Properties/Resources.zh-tw.resx b/Properties/Resources.zh-tw.resx
index af855cc..806fac3 100644
--- a/Properties/Resources.zh-tw.resx
+++ b/Properties/Resources.zh-tw.resx
@@ -224,7 +224,7 @@
已啟用「包含全域結果中」選項於History插件,可能會與 EPT 發生衝突。
-
+
右鍵選單 (Ctrl+M)
diff --git a/plugin.json b/plugin.json
index 16f1f52..a96a340 100644
--- a/plugin.json
+++ b/plugin.json
@@ -4,7 +4,7 @@
"IsGlobal": true,
"Name": "Everything",
"Author": "Yu Chieh (Victor) Lin",
- "Version": "0.0.2",
+ "Version": "0.88.0",
"Language": "csharp",
"Website": "https://github.com/Lin-ycv/EverythingPowerToys",
"ExecuteFileName": "Community.PowerToys.Run.Plugin.Everything.dll",
diff --git a/ContextMenu/ContextMenuLoader.cs b/ContextMenu/ContextMenuLoader.cs
index 0656266..4823f2d 100644
--- a/ContextMenu/ContextMenuLoader.cs
+++ b/ContextMenu/ContextMenuLoader.cs
@@ -6,6 +6,7 @@ using System.Reflection;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Input;
+using Community.PowerToys.Run.Plugin.Everything.Interop;
using Community.PowerToys.Run.Plugin.Everything.Properties;
using Community.PowerToys.Run.Plugin.Everything.SearchHelper;
using Wox.Infrastructure;
@@ -62,9 +63,11 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
{
var message = $"{Resources.folder_open_failed} {Path.GetDirectoryName(record.Path)}";
_context.API.ShowMsg(message);
+ Log.Exception($"EPT: Failed to open folder {Path.GetDirectoryName(record.Path)}", new IOException(), GetType());
return false;
}
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
},
});
@@ -88,11 +91,12 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
Task.Run(() => Helper.RunAsAdmin(record.Path));
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
- Log.Exception($"Failed to run {record.Path} as admin, {e.Message}", e, MethodBase.GetCurrentMethod().DeclaringType);
+ Log.Exception($"EPT: Failed to run {record.Path} as admin", e, GetType());
return false;
}
},
@@ -117,11 +121,12 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
Task.Run(() => Helper.RunAsUser(record.Path));
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
- Log.Exception($"Failed to run {record.Path} as different user, {e.Message}", e, MethodBase.GetCurrentMethod().DeclaringType);
+ Log.Exception($"EPT: Failed to run {record.Path} as different user", e, GetType());
return false;
}
},
@@ -145,12 +150,13 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
Clipboard.SetData(DataFormats.FileDrop, new string[] { record.Path });
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
var message = Resources.clipboard_failed;
- Log.Exception(message, e, GetType());
+ Log.Exception($"ETP3: Failed to copy {(_swapCopy ? "file" : "path")} ({record.Path}) to clipboard", e, GetType());
_context.API.ShowMsg(message);
return false;
@@ -174,12 +180,13 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
Clipboard.SetDataObject(record.Path);
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
var message = Resources.clipboard_failed;
- Log.Exception(message, e, GetType());
+ Log.Exception($"ETP3: Failed to copy {(_swapCopy ? "file" : "path")} ({record.Path}) to clipboard", e, GetType());
_context.API.ShowMsg(message);
return false;
@@ -203,19 +210,16 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
if (isFile)
- {
Helper.OpenInConsole(Path.GetDirectoryName(record.Path));
- }
else
- {
Helper.OpenInConsole(record.Path);
- }
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
- Log.Exception($"Failed to open {record.Path} in console, {e.Message}", e, GetType());
+ Log.Exception($"EPT: Failed to open {record.Path} in console", e, GetType());
return false;
}
},
@@ -240,11 +244,12 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
try
{
process.Start();
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
- Log.Exception($"Failed to execute {_customProgram} with arguments {_customArg}", e, GetType());
+ Log.Exception($"EPT: Failed to execute {_customProgram} with arguments {_customArg}", e, GetType());
return false;
}
},
@@ -272,18 +277,18 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
}
catch (Exception e)
{
- Log.Exception($"Failed to delete {record.Path}", e, GetType());
+ Log.Exception($"EPT: Failed to delete {record.Path}", e, GetType());
return false;
}
},
});
break;
case '8':
// Right Click Context Menu
contextMenus.Add(new ContextMenuResult
{
PluginName = Assembly.GetExecutingAssembly().GetName().Name,
- Title = Resources.right_click,
+ Title = Resources.scm,
Glyph = "\xE712",
FontFamily = "Segoe MDL2 Assets",
AcceleratorKey = Key.M,
@@ -297,11 +302,12 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
scm.ShowContextMenu(new FileInfo(record.Path), wf.Cursor.Position);
else
scm.ShowContextMenu(new DirectoryInfo(record.Path), wf.Cursor.Position);
+ NativeMethods.Everything_IncRunCountFromFileNameW(record.Path);
return true;
}
catch (Exception e)
{
- Log.Exception($"Failed to open right click context menu for {record.Path}", e, GetType());
+ Log.Exception($"EPT: Failed to open shell context menu for {record.Path}", e, GetType());
return false;
}
},
@@ -323,9 +329,7 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
{
// Using OrdinalIgnoreCase since this is internal
if (extension.Equals(fileExtension, StringComparison.OrdinalIgnoreCase))
- {
return true;
- }
}
return false;
@@ -272,18 +277,18 @@ namespace Community.PowerToys.Run.Plugin.Everything.ContextMenu
break;
case '8':
- // Right Click Context Menu
+ // Shell Context Menu
contextMenus.Add(new ContextMenuResult
{